@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 
 package Dist::Zilla::PluginBundle::Author::KENTNL;
-$Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '2.011000';
+$Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '2.011001';
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -133,10 +133,16 @@ has 'mantissa' => (
 );
 
 has 'git_versions' => ( is => 'ro', isa => enum( [1] ), required => 1, );
-has 'authority'               => ( is => 'ro', isa   => 'Str',      lazy => 1, builder => sub { 'cpan:KENTNL' }, );
-has 'auto_prereqs_skip'       => ( is => 'ro', isa   => 'ArrayRef', lazy => 1, builder => sub { [] }, );
-has 'twitter_extra_hash_tags' => ( is => 'ro', 'isa' => 'Str',      lazy => 1, builder => sub { q[] }, );
-has 'twitter_hash_tags'       => (
+has 'authority' => ( is => 'ro', isa => 'Str', lazy => 1, builder => sub { 'cpan:KENTNL' }, );
+has 'auto_prereqs_skip' => (
+  is        => 'ro',
+  isa       => 'ArrayRef',
+  predicate => 'has_auto_prereqs_skip',
+  lazy      => 1,
+  builder   => sub { [] },
+);
+has 'twitter_extra_hash_tags' => ( is => 'ro', 'isa' => 'Str', lazy => 1, builder => sub { q[] }, );
+has 'twitter_hash_tags' => (
   is      => 'ro',
   isa     => 'Str',
   lazy    => 1,
@@ -275,7 +281,11 @@ sub configure {
 
   # Prereqs
 
-  $self->add_plugin( 'AutoPrereqs' => { skip => $self->auto_prereqs_skip } );
+  {
+    my $autoprereqs_hash = {};
+    $autoprereqs_hash->{skips} = $self->auto_prereqs_skip if $self->has_auto_prereqs_skip;
+    $self->add_plugin( 'AutoPrereqs' => $autoprereqs_hash );
+  }
   $self->add_named_plugin(
     'BundleDevelSuggests' => 'Prereqs' => {
       -phase                                            => 'develop',
@@ -326,7 +336,7 @@ sub configure {
   $self->add_plugin( 'UploadToCPAN' => {} );
   $self->add_plugin( 'Twitter' => { hash_tags => $self->twitter_hash_tags, tweet_url => $self->tweet_url } );
 
-  my @extra_match_installed = qw( Test::More Dist::Zilla::PluginBundle::Author::KENTNL );
+  my @extra_match_installed = qw( Test::More );
   unshift @extra_match_installed, 'Module::Build'       if 'mb' eq $self->toolkit;
   unshift @extra_match_installed, 'Module::Build::Tiny' if 'mbtiny' eq $self->toolkit;
   unshift @extra_match_installed, 'ExtUtils::MakeMaker' if 'eumm' eq $self->toolkit;
@@ -345,6 +355,14 @@ sub configure {
       },
     );
   }
+
+  $self->add_named_plugin(
+    'always_latest_develop_bundle' => 'Prereqs::Recommend::MatchInstalled' => {
+      applyto_map   => [ 'develop.requires = develop.requires', ],
+      applyto_phase => [ 'develop', ],
+      modules       => [ qw( Dist::Zilla::PluginBundle::Author::KENTNL ), ],
+    },
+  );
   return;
 }
 
@@ -381,7 +399,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.011000
+version 2.011001
 
 =head1 SYNOPSIS
 
